- Replaced more references of bopm with hopm
authormichael <michael@82007160-df01-0410-b94d-b575c5fd34c7>
Mon, 22 Dec 2014 14:57:12 +0000 (14:57 +0000)
committermichael <michael@82007160-df01-0410-b94d-b575c5fd34c7>
Mon, 22 Dec 2014 14:57:12 +0000 (14:57 +0000)
git-svn-id: svn://svn.ircd-hybrid.org/svnroot/hopm/trunk@5069 82007160-df01-0410-b94d-b575c5fd34c7

doc/reference.conf
src/Makefile.am
src/Makefile.in
src/config.c
src/firedns.h
src/irc.c
src/main.c
src/opercmd.c

index 30512122d5beb4fe048d76d57d05259af03d1dfa..06ba868bcb23893a92a47fc8841b5c12241fe7fb 100644 (file)
@@ -117,7 +117,7 @@ IRC {
         * If this is set then HOPM will use it as an /away message as soon as
         * it connects.
         */
-       away = "I'm a bot.  Your messages will be ignored.";
+       away = "I'm a bot. Your messages will be ignored.";
 
        /*
         * Info about channels you wish HOPM to join in order to accept
index 5ee9f991e539ac69e2ebb5180d01341de6defc28..cbaad7326333ca27928137e432516225489881b4 100644 (file)
@@ -2,7 +2,7 @@ SUBDIRS = libopm .
 
 bin_PROGRAMS = hopm
 
-AM_CPPFLAGS = -DBOPM_ETCDIR="\"$(sysconfdir)\"" -DBOPM_LOGDIR="\"$(localstatedir)\""
+AM_CPPFLAGS = -DHOPM_ETCDIR="\"$(sysconfdir)\"" -DHOPM_LOGDIR="\"$(localstatedir)\""
 AM_YFLAGS = -d
 
 hopm_SOURCES = compat.c compat.h config-parser.y config-lexer.l config.c config.h \
index 5b5f40cc1b263bb09870c356430749a1f0ad32e8..9e234c9e755e864f1bfbbc2a64ea8ee7dee3f8b0 100644 (file)
@@ -351,7 +351,7 @@ top_build_prefix = @top_build_prefix@
 top_builddir = @top_builddir@
 top_srcdir = @top_srcdir@
 SUBDIRS = libopm .
-AM_CPPFLAGS = -DBOPM_ETCDIR="\"$(sysconfdir)\"" -DBOPM_LOGDIR="\"$(localstatedir)\""
+AM_CPPFLAGS = -DHOPM_ETCDIR="\"$(sysconfdir)\"" -DHOPM_LOGDIR="\"$(localstatedir)\""
 AM_YFLAGS = -d
 hopm_SOURCES = compat.c compat.h config-parser.y config-lexer.l config.c config.h \
     dnsbl.c dnsbl.h extern.h inet.c inet.h irc.c irc.h log.c log.h main.c match.c \
index b08eddb0fb413d7ab6743743b3bb6737c48c5e1b..c04cc1b6e7dd2abc4b72c154de61240a04dd3342 100644 (file)
@@ -120,24 +120,24 @@ void config_setup()
 {
 
    /* Setup IRC Block Defaults */
-   IRCItem->away = DupString("I'm a bot, don't message me");
+   IRCItem->away = DupString("I'm a bot. Your messages will be ignored.");
    IRCItem->mode = DupString("+cs");
-   IRCItem->nick = DupString("bopm");
+   IRCItem->nick = DupString("hopm");
    IRCItem->nickserv = DupString("");
    IRCItem->password = DupString("");
    IRCItem->port = 6667;
    IRCItem->oper = DupString("undefined");
-   IRCItem->username = DupString("bopm");
-   IRCItem->realname = DupString("Blitzed Open Proxy Monitor");
+   IRCItem->username = DupString("hopm");
+   IRCItem->realname = DupString("Hybrid Open Proxy Monitor");
    IRCItem->server = DupString("myserver.blitzed.org");
    IRCItem->vhost = DupString("");
    IRCItem->connregex = DupString("\\*\\*\\* Notice -- Client connecting: ([^ ]+) \\(([^@]+)@([^\\)]+)\\) \\[([0-9\\.]+)\\].*");
-   IRCItem->kline = DupString("KLINE %u@%h :Open Proxy found on your host. Please visit www.blitzed.org/proxy?ip=%i for more information.");
+   IRCItem->kline = DupString("KLINE %u@%h :Open Proxy found on your host.");
 
 
    /* Setup options block defaults */
    OptionsItem->negcache = 0;   /* 0 disabled negcache */
-   OptionsItem->pidfile = DupString("bopm.pid");
+   OptionsItem->pidfile = DupString("hopm.pid");
    OptionsItem->dns_fdlimit = 50;
    OptionsItem->scanlog = NULL;
 
index 2c3e50c3b8a867c6cd81a2a64b5b41e320126f1b..6432dec7089ba0ae0d87f45d136692ad86be2002 100644 (file)
@@ -36,7 +36,7 @@ struct in6_addr {
 /* max number of nameservers used */
 #define FDNS_MAX              8
 /* preferred firedns config file */
-#define FDNS_CONFIG_PREF     BOPM_ETCDIR "/firedns.conf"
+#define FDNS_CONFIG_PREF     HOPM_ETCDIR "/firedns.conf"
 /* fallback config file */
 #define FDNS_CONFIG_FBCK     "/etc/resolv.conf"
 /* Number of seconds to wait for a reply */
index a34d60cbf006fca76f855408d36365a43c81b941..22ba89783380b99d94e1528a5685c180d8e0393d 100644 (file)
--- a/src/irc.c
+++ b/src/irc.c
@@ -137,7 +137,7 @@ static struct CommandHash COMMAND_TABLE[] = {
 
 /* irc_cycle
  *
*    Pass control to the IRC portion of BOPM to handle any awaiting IRC events.
  *
  * Parameters:
  *    None
@@ -655,7 +655,7 @@ void irc_timer(void)
        * ircds (*cough* unreal *cough*) don't cause uneeded
        * reconnections
        */
-      irc_send("PING :BOPM");
+      irc_send("PING :HOPM");
    }
 
 }
@@ -1071,7 +1071,7 @@ static void m_notice(char **parv, unsigned int parc, char *msg, struct UserInfo
  *
  * parv[0]  = source
  * parv[1]  = USERHOST
- * parv[2]  = target (bopm)
+ * parv[2]  = target (hopm)
  * parv[3]  = :nick=(flags)user@host
  *
  *
@@ -1096,7 +1096,7 @@ static void m_userhost(char **parv, unsigned int parc, char *msg,
  *
  * parv[0]  = source
  * parv[1]  = numeric
- * parv[2]  = target (bopm)
+ * parv[2]  = target (hopm)
  * parv[3]  = channel
  * parv[4]  = error text
  *
@@ -1128,7 +1128,7 @@ static void m_cannot_join(char **parv, unsigned int parc, char *msg,
  *
  * parv[0]  = source
  * parv[1]  = numeric
- * parv[2]  = target (bopm)
+ * parv[2]  = target (hopm)
  * parv[3]  = channel
  * parv[4]  = error text
  *
@@ -1141,6 +1141,6 @@ static void m_kill(char **parv, unsigned int parc, char *msg, struct UserInfo *s
    USE_VAR(msg);
    USE_VAR(source_p);
 
/* Restart bopm to rehash */
    main_restart();
 }
index 9266f4ba74d4f2a0078e7111dc8d668556127e4b..5dfc9c5cdd7c906b2f62fa7f7d81c827b9f7a543 100644 (file)
@@ -65,8 +65,8 @@ int REOPEN  = 0;             /* Flagged to reopen log files on next cycle */
 unsigned int OPT_DEBUG = 0;  /* Debug level */
 
 char *CONFNAME = DEFAULTNAME;
-char *CONFDIR = BOPM_ETCDIR;
-char *LOGDIR = BOPM_LOGDIR;
+char *CONFDIR = HOPM_ETCDIR;
+char *LOGDIR = HOPM_LOGDIR;
 char *CONFFILE, *LOGFILE;
 
 struct sigaction ALARMACTION;
@@ -153,7 +153,7 @@ int main(int argc, char **argv)
       log_printf("MAIN -> Debug level %d", OPT_DEBUG);
 
 
-   log_printf("MAIN -> BOPM %s started.", VERSION);
+   log_printf("MAIN -> HOPM %s started.", VERSION);
    log_printf("MAIN -> Reading configuration file...");
 
    config_load(CONFFILE);
index ec59502e81a2fa53c85281319d8e5b05ac4e592f..970e7e5731dc1f5aaa00e30853389f10d7d7952e 100644 (file)
@@ -133,7 +133,7 @@ void command_timer()
 
 /* command_parse
  *
*    Parse a command to bopm (sent to a channel bopm is on). The command is parsed
  *    from the parameters, and if it is a known command it is stored in a queue. A
  *    userhost is performed on the user to check if they are an IRC operator. When
  *    a reply is returned (command_userhost), the command will be executed.
@@ -334,7 +334,7 @@ void command_userhost(char *reply)
 
 /* cmd_check
  *
*    Start a manual scan on given IP. Parameter MUST be an IP. BOPM should not
  *    have to waste any time resolving a hostname.
  *
  * Parameters:
@@ -137,7 +137,7 @@ static struct CommandHash COMMAND_TABLE[] = {
 /* irc_cycle
  *
- *    Pass control to the IRC portion of BOPM to handle any awaiting IRC events.
+ *    Pass control to the IRC portion of HOPM to handle any awaiting IRC events.
  *
  * Parameters:
@@ -1141,6 +1141,6 @@ static void m_kill(char **parv, unsigned int parc, char *msg, struct UserInfo *s
    USE_VAR(source_p);
 
-   /* Restart bopm to rehash */
+   /* Restart hopm to rehash */
    main_restart();
 }
@@ -133,7 +133,7 @@ void command_timer()
 /* command_parse
  *
- *    Parse a command to bopm (sent to a channel bopm is on). The command is parsed
+ *    Parse a command to hopm (sent to a channel hopm is on). The command is parsed
  *    from the parameters, and if it is a known command it is stored in a queue. A
  *    userhost is performed on the user to check if they are an IRC operator. When
@@ -334,7 +334,7 @@ void command_userhost(char *reply)
 /* cmd_check
  *
- *    Start a manual scan on given IP. Parameter MUST be an IP. BOPM should not
+ *    Start a manual scan on given IP. Parameter MUST be an IP. HOPM should not
  *    have to waste any time resolving a hostname.
  *